import { e as error, d as private_env } from './index-CTfgkdxe.js';
import { create } from 'youtube-dl-exec';
import { spawn } from 'node:child_process';
import { s as supportedFormats } from './supportedFormats-DgxuDFwo.js';

const formatMime = new Map(Object.entries(supportedFormats));
const isURLValid = (url) => {
  try {
    new URL(url);
  } catch {
    return false;
  }
  return true;
};
const mimeTypeMap = formatMime;
const contentTypeFromFormat = (format) => {
  const toReturn = formatMime.get(format);
  if (!toReturn) {
    throw new Error("Unsupported format");
  }
  return toReturn;
};
const YTDLP_PATH = private_env.YTDLP_PATH;
const ytdl = create(YTDLP_PATH);
async function getYouTubeMetadata(link) {
  return await ytdl(link, {
    dumpSingleJson: true,
    noCheckCertificates: true,
    noWarnings: true,
    preferFreeFormats: true
  });
}
function streamYouTube(link, format) {
  const mimeType = mimeTypeMap.get(format);
  if (!mimeType) {
    throw new Error("Unsupported format");
  }
  return new ReadableStream({
    start(controller) {
      const args = [
        "-o",
        "-"
      ].filter(Boolean);
      if (mimeType?.includes("audio")) {
        args.push(...["--extract-audio", "--embed-metadata", "--embed-thumbnail", "--audio-format", format]);
      } else if (mimeType.includes("video")) {
        args.push(...["--embed-metadata", "--embed-thumbnail", "--format", format]);
      }
      console.info(`yt-dlp ${args.join(" ")} ${link}`);
      const process = spawn("yt-dlp", [...args, link], { stdio: ["ignore", "pipe", "ignore"] });
      process.stdout.on("data", (chunk) => controller.enqueue(chunk));
      process.stdout.on("end", () => controller.close());
      process.stdout.on("error", (err) => {
        console.error("Stream error:", err);
        controller.error(err);
      });
    }
  });
}
const validateRequest = (url) => {
  const link = url.searchParams.get("link");
  const format = url.searchParams.get("format");
  const source = url.searchParams.get("source");
  const metadata = url.searchParams.get("metadata");
  if (!link || !format || !source) {
    throw error(400, "Missing required query parameters: link, format, or source");
  }
  if (source !== "youtube") {
    throw error(400, "Currently, only YouTube is supported");
  }
  if (!isURLValid(link)) {
    throw error(400, "URL not valid");
  }
  if (!mimeTypeMap.get(format)) {
    throw error(400, "format not valid");
  }
  return {
    link,
    format,
    source,
    metadata
  };
};
const GET = async ({ url }) => {
  const { format, metadata, link } = validateRequest(url);
  let filename = `you-clicked-no-metadata-so-i-cant-put-a-correct-name.${format}`;
  if (metadata) {
    try {
      const metadata2 = await getYouTubeMetadata(link);
      const { title, uploader } = metadata2;
      const safeTitle = `${uploader} - ${title}`;
      filename = `${safeTitle}.${format}`;
    } catch (err) {
      console.error(err);
      console.error("Error fetching metadata:");
      throw error(500, "Failed to fetch video metadata");
    }
  }
  try {
    return new Response(streamYouTube(link, format), {
      headers: {
        "Content-Type": contentTypeFromFormat(format),
        "Content-Disposition": `attachment; filename="${filename}"`,
        "Set-Cookie": "downloading=0"
      }
    });
  } catch (err) {
    console.error(err);
    console.error("Filed to stream file");
    throw error(500, "Failed to stream file");
  }
};

export { GET };
//# sourceMappingURL=_server.ts-C6-a83c4.js.map
